@@ -1,8 +1,8 @@
 from urge.base import ProcManager, action
 from path import Path
+import time
 
-
-def web_screenshot(url: str, target: str = "./", use_mobile=True, **kwargs) -> str:
+def web_screenshot(url: str, target: str = "./", use_mobile=True, full_page=False, time_out=2, **kwargs) -> str:
 
     from playwright.sync_api import sync_playwright
     from datetime import datetime
@@ -28,13 +28,21 @@ def web_screenshot(url: str, target: str = "./", use_mobile=True, **kwargs) -> s
             page.set_viewport_size({"width": 375, "height": 635})
 
         page.goto(url, wait_until="networkidle")
-        # page.screenshot(path=f'./example-{browser_type.name}haha.png')
+        
+        if full_page is True:
+            start = time.time()
+            while True:
+                page.keyboard.press("PageDown")
+                now = time.time()
+                if now - start > time_out:
+                    break
+            
         target = Path(target)
         file_name = (
             target / f'screenshot{datetime.now().strftime("%m-%d-%H-%M-%S")}.png'
         )
-        page.screenshot(path=file_name, type="jpeg", quality=20)
-        # page.screenshot(path=file_name, type="png")
+        page.screenshot(path=file_name, type="jpeg", quality=20, full_page=full_page)
+        # page.screenshot(path=file_name, type="png", full_page=full_page)
         print(f"🤖 : DONE")
         print(f"The file is at {file_name}")
         browser.close()
