@@ -21,7 +21,16 @@ def ret_weather(
         result = pq.find("pre")
         return str(result.text(squash_space=False))
     temp = res.json().get("current_condition")
-    return float(temp[0].get("FeelsLikeC"))
+    temp_str = temp[0].get("FeelsLikeC")
+    
+    if temp_str is None or temp_str == "":
+        raise ValueError("The city_string you entered is wrong. Please re-enter")
+    try:
+        ret = int(temp_str)
+    except:
+        ret = float(temp_str)
+    finally:
+        return ret
 
 
 def get_now_temp(city: str, ascii_graphs: bool = True):
