@@ -1,4 +1,5 @@
 import os
+
 # import json
 import httpx
 from httpx import Response
@@ -45,7 +46,7 @@ def post_builder(name, **kwd):
                 params={**_query, **_config.CONFIG, **kwd},
             )
             resp = httpx.post(**_params)
-            _resp =resp.json() 
+            _resp = resp.json()
             code = int(_resp["code"])
             if code != 200:
                 raise Exception("Something wrong with XJ's service wraper")
@@ -85,7 +86,8 @@ def trans_filter(res: Result, full=False):
         # if basic exists, q must be one word,
         basic = utils.drop(basic, keys=["us-speech", "uk-speech"])
         basic["web_dict"] = res.result.get("webdict").get("url")
-        d["simple_translation"] = res.result.get("translation")[0]
+        _trans = res.result.get("translation")
+        d["simple_translation"] = _trans
         d.update(basic)
         if not full:
             d = d.get("explains")
